@@ -1,10 +1,7 @@
 package #
     TestApp;
-use Moose;
-extends 'Catalyst';
+use base 'Catalyst';
 
 __PACKAGE__->setup;
 
-no Moose;
-
 1;
